==> haskell-http-client-restricted-0.1.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-GN6590N1NdOCI578GthTe0
key:                  http-client-restricted-0.1.0-GN6590N1NdOCI578GthTe0
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  ca42ac40285261850ed499cdc66f432a
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-GN6590N1NdOCI578GthTe0
depends:
    base-4.16.4.0 crypton-connection-0.3.2-3H8l6Zl0ceOLAjF7cPfdkF
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    http-client-0.7.15-1rEunxZVzGx9PhfeNag7Vk
    http-client-tls-0.3.6.3-H1Gd4S816EhHsdCpWSwn77
    network-3.1.4.0-42vrGNOyyN5EQENmFarxRS
    network-bsd-2.8.1.0-85JxGhTFQ9k5mElQHkdjGq
    utf8-string-1.0.2-CndrelvclEbJyymwdX0DqC

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-restricted-0.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-HIUoj4PGjAIYWN1uV2VZD
key:                  http-client-restricted-0.1.0-HIUoj4PGjAIYWN1uV2VZD
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  88e1c37fcdab01d7cc3a2f82ca6d6587
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-HIUoj4PGjAIYWN1uV2VZD
depends:
    base-4.16.4.0 crypton-connection-0.3.2-Cya63EMGJyo4PtWLeXm9Tw
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    http-client-0.7.15-CfCS6ksdsf15aPqpZ0VwYm
    http-client-tls-0.3.6.3-Ly2SIcVuwJBTAdkdfNBFA
    network-3.1.4.0-HWJHph1qrvp6tEtZHv7We0
    network-bsd-2.8.1.0-LOdyT3bHCssArRYM5nM8Kb
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
